import { Component, OnInit, ChangeDetectorRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NavbarComponent } from '@shared/components/navbar/navbar.component';
import { LootboxService } from '../services/lootbox.service';
import { LootBox } from 'app/model/LootBox';
import { Router } from '@angular/router';
import { timeout } from 'rxjs';

@Component({
  selector: 'app-lootbox-selection',
  standalone: true,
  imports: [CommonModule, NavbarComponent],
  templateUrl: './lootbox-selection.component.html',
  styleUrls: ['./lootbox-selection.component.css']
})
export default class LootboxSelectionComponent implements OnInit {
  lootboxes: LootBox[] = [];
  isLoading = true;
  error = '';

  // Fallback data in case the API call fails
  fallbackLootboxes: LootBox[] = [
    {
      id: 1,
      name: "Basic LootBox",
      price: 2.00,
      rewards: [
        {
          id: 1,
          value: 0.50,
          probability: 0.70
        },
        {
          id: 5,
          value: 5.00,
          probability: 0.30
        }
      ]
    },
    {
      id: 2,
      name: "Premium LootBox",
      price: 5.00,
      rewards: [
        {
          id: 4,
          value: 2.00,
          probability: 0.60
        },
        {
          id: 5,
          value: 5.00,
          probability: 0.30
        },
        {
          id: 6,
          value: 15.00,
          probability: 0.10
        }
      ]
    },
    {
      id: 3,
      name: "Legendäre LootBox",
      price: 15.00,
      rewards: [
        {
          id: 4,
          value: 2.00,
          probability: 0.60
        },
        {
          id: 5,
          value: 5.00,
          probability: 0.30
        },
        {
          id: 6,
          value: 15.00,
          probability: 0.10
        }
      ]
    }
  ];

  constructor(private lootboxService: LootboxService, private router: Router, private cdr: ChangeDetectorRef) {}

  ngOnInit(): void {
    this.loadLootboxes();
  }

  loadLootboxes(): void {
    this.isLoading = true;
    this.lootboxService.getAllLootBoxes().pipe(
      timeout(5000)
    ).subscribe({
      next: (data) => {
        console.log('Received lootboxes:', data);
        this.lootboxes = data;
        this.isLoading = false;
        this.cdr.detectChanges();
      },
      error: (err) => {
        this.error = 'Konnte keine Verbindung zum Backend herstellen. Zeige Demo-Daten.';
        this.lootboxes = this.fallbackLootboxes;
        this.isLoading = false;
        this.cdr.detectChanges();
        console.error('Failed to load lootboxes:', err);
      }
    });
  }

  getBoxImage(id: number): string {
    return `/images/${id}-box.png`;
  }

  openLootbox(lootboxId: number): void {
    this.router.navigate(['/game/lootboxes/open', lootboxId]);
  }

  getRarityClass(probability: number): string {
    if (probability <= 0.1) {
      return 'text-yellow-400'; // Legendary
    } else if (probability <= 0.3) {
      return 'text-purple-400'; // Rare
    } else {
      return 'text-blue-400'; // Common
    }
  }

  formatProbability(probability: number): string {
    return (probability * 100).toFixed(0) + '%';
  }
} 